==> breeze_website_builder_6.5.0.tar.gz: manage/plugins/lang/gallery/eu.php <==
<?php
////////////////////////////////////////////////////////////////////////
// Breeze Website Builder
// Copyright Silver Dolphin Solutions, LLC, Edward Lemmers, P.E.
// For licensing, see license.txt.
// Created: 3/1/2015	ELL

///////////////////////// Manage Gallery Parameters /////////////////////////
// Buttons:
define('MANAGE_GALLERY_HEADING', "Kudeatu Etiketa Gallary parametroak");
define('MANAGE_GALLERY_MANAGE_GALLERY_BTN', "Kudeatu Gallery");
// Console Text:
define('MANAGE_GALLERY_FULL_WIDTH', "Tamaina osoko irudia Zabalera");
define('MANAGE_GALLERY_FULL_HEIGHT', "Tamaina osoko irudia Altuera");
define('MANAGE_GALLERY_THUMB_WIDTH', "Thumbnail Irudiaren zabalera");
define('MANAGE_GALLERY_THUMB_HEIGHT', "Thumbnail Image Altuera");
define('MANAGE_GALLERY_PRESERVE_THUMB_ASPECT', "Ganboa Thumb Aspektu");
define('MANAGE_GALLERY_SHOW_TITLES', "Erakutsi Izenburuak");
define('MANAGE_GALLERY_DISABLE_SORT', "Disable ordenatu");
define('MANAGE_GALLERY_DELETE_IMAGE', "ezabatu irudia");
define('MANAGE_GALLERY_SAVE_SORT_ORDER', "Save ordenara");
define('MANAGE_GALLERY_PUBLISH_MSG', "Egin klik &#39;Eguneratu&#39; argitaratzeko <br /> Zure igotako irudiak.");
// Popup Messages:
define('MANAGE_GALLERY_UPDATE_SUCCESS_MSG', "irudi guztiak tamaina aldatu dira eta ezarpenak gorde dira.");
define('MANAGE_GALLERY_UPDATE_FAIL_ERR', "Akats baten irudiak tamainaz aldatu edo ezarpenak gordetzerakoan.");
define('MANAGE_GALLERY_UPLOAD_SUCCESS_MSG', "Zure irudia (s) kargatu da.");
define('MANAGE_GALLERY_UPLOAD_FAIL_ERR', "Errore bat gertatu da irudia (s) kargatzean.");
define('MANAGE_GALLERY_UPLOAD_NOT_IMAGE_ERR', "Kargatzen saiatzen ari zaren fitxategia ez da irudi bat.");
define('MANAGE_GALLERY_UPLOAD_TOO_BIG_ERR', "Kargatzen saiatzen ari zaren fitxategia handiegia da.");
define('MANAGE_GALLERY_UPDATE_TITLE_SUCCESS_MSG', "titulua gorde da.");
define('MANAGE_GALLERY_DELETE_IMAGE_CONFIRM_1_MSG', "Ziur zaude irudia ezabatu nahi dituzula");
define('MANAGE_GALLERY_DELETE_IMAGE_CONFIRM_2_MSG', "?");
define('MANAGE_GALLERY_DELETE_IMAGE_SUCCESS_MSG', "irudia ezabatu da.");
define('MANAGE_GALLERY_DELETE_IMAGE_FAIL_ERR', "Errorea irudia ezabatzean.");
define('MANAGE_GALLERY_SAVING_PARAMS_MSG', "parametro Aurrezteko eta irudiak tamainaz aldatu, itxaron ...");
define('MANAGE_GALLERY_UPLOADING_IMAGES_MSG', "Datuak igotzea, itxaron ...");
define('MANAGE_GALLERY_NOT_SAVED_MSG', "Ordena ez da gorde. Ez Ordena gorde nahi duzu?");
define('MANAGE_GALLERY_SAVE_SORT_ORDER_SUCCESS_MSG', "irudia ordenara gorde da.");
define('MANAGE_GALLERY_SAVE_SORT_ORDER_FAIL_ERR', "Errorea irudia moduko gordetzean.");
?>

==> breeze_website_builder_6.6.18.tar.gz: manage/plugins/lang/gallery/eu.php <==
<?php
////////////////////////////////////////////////////////////////////////
// Breeze Website Builder
// Copyright Silver Dolphin Solutions, LLC, Edward Lemmers, P.E.
// For licensing, see license.txt.
// Created: 3/1/2015	ELL

///////////////////////// Manage Gallery Parameters /////////////////////////
// Buttons:
define('MANAGE_GALLERY_HEADING', "Kudeatu Etiketa Gallary parametroak");
define('MANAGE_GALLERY_MANAGE_GALLERY_BTN', "Kudeatu Gallery");
// Console Text:
define('MANAGE_GALLERY_FULL_WIDTH', "Tamaina osoko irudia Zabalera");
define('MANAGE_GALLERY_FULL_HEIGHT', "Tamaina osoko irudia Altuera");
define('MANAGE_GALLERY_THUMB_WIDTH', "Thumbnail Irudiaren zabalera");
define('MANAGE_GALLERY_THUMB_HEIGHT', "Thumbnail Image Altuera");
define('MANAGE_GALLERY_PRESERVE_THUMB_ASPECT', "Ganboa Thumb Aspektu");
define('MANAGE_GALLERY_SHOW_TITLES', "Erakutsi Izenburuak");
define('MANAGE_GALLERY_DISABLE_SORT', "Disable ordenatu");
define('MANAGE_GALLERY_DELETE_IMAGE', "ezabatu irudia");
define('MANAGE_GALLERY_SAVE_SORT_ORDER', "Save ordenara");
define('MANAGE_GALLERY_PUBLISH_MSG', "Egin klik &#39;Eguneratu&#39; argitaratzeko <br /> Zure igotako irudiak.");
// Popup Messages:
define('MANAGE_GALLERY_UPDATE_SUCCESS_MSG', "irudi guztiak tamaina aldatu dira eta ezarpenak gorde dira.");
define('MANAGE_GALLERY_UPDATE_FAIL_ERR', "Akats baten irudiak tamainaz aldatu edo ezarpenak gordetzerakoan.");
define('MANAGE_GALLERY_UPLOAD_SUCCESS_MSG', "Zure irudia (s) kargatu da.");
define('MANAGE_GALLERY_UPLOAD_FAIL_ERR', "Errore bat gertatu da irudia (s) kargatzean.");
define('MANAGE_GALLERY_UPLOAD_NOT_IMAGE_ERR', "Kargatzen saiatzen ari zaren fitxategia ez da irudi bat.");
define('MANAGE_GALLERY_UPLOAD_TOO_BIG_ERR', "Kargatzen saiatzen ari zaren fitxategia handiegia da.");
define('MANAGE_GALLERY_UPDATE_TITLE_SUCCESS_MSG', "titulua gorde da.");
define('MANAGE_GALLERY_DELETE_IMAGE_CONFIRM_1_MSG', "Ziur zaude irudia ezabatu nahi dituzula");
define('MANAGE_GALLERY_DELETE_IMAGE_CONFIRM_2_MSG', "?");
define('MANAGE_GALLERY_DELETE_IMAGE_SUCCESS_MSG', "irudia ezabatu da.");
define('MANAGE_GALLERY_DELETE_IMAGE_FAIL_ERR', "Errorea irudia ezabatzean.");
define('MANAGE_GALLERY_SAVING_PARAMS_MSG', "parametro Aurrezteko eta irudiak tamainaz aldatu, itxaron ...");
define('MANAGE_GALLERY_UPLOADING_IMAGES_MSG', "Datuak igotzea, itxaron ...");
define('MANAGE_GALLERY_NOT_SAVED_MSG', "Ordena ez da gorde. Ez Ordena gorde nahi duzu?");
define('MANAGE_GALLERY_SAVE_SORT_ORDER_SUCCESS_MSG', "irudia ordenara gorde da.");
define('MANAGE_GALLERY_SAVE_SORT_ORDER_FAIL_ERR', "Errorea irudia moduko gordetzean.");
define('MANAGE_GALLERY_UPLOAD_BIGGER_THAN_ALLOWED_ERR', "Kargatzen saiatzen ari zaren fitxategia &#39;upload_max_filesize&#39; edo &#39;post_max_size&#39; PHP ezarpenak baino handiagoa da. Jarri harremanetan sistemako administratzailearekin muga horiek gehitzeko.");
?>
